Gilfoyle: Report generator - Examples

# Gilfoyle: Report generator

## Cover page

# Chapter page

## Chapter pages separate content

# Report: simple

Your report commentary goes in here. On the simple layout, there's only room for a few lines of text, so be sparing with your words to avoid the content overflowing to the next page.

# Report: left-commentary

The left-commentary report has loads of room for text and can also handle a row of metrics across the top of the page.

This is a message. Changing the message style alters its colour.
This is a notification. It goes in a pale grey box.
Dataframe goes here